#!/bin/sh
set +x
#
#    Licensed Materials - Property of IBM
#
#    "Restricted Materials of IBM"
#
#    5724-U38, 5724-U39, 5724-U48
#
#     Copyright IBM Corp. 2018 All Rights Reserved
#
#     Copyright 2018 UNICOM Systems, Inc. - All Rights Reserved
#
#    US Government Users Restricted Rights - Use, duplication or
#    disclosure restricted by GSA ADP Schedule Contract with
#    IBM Corp.
#
# Syntax:
# CopyRTFiles.sh source_rt_dir target_rt_dir
#
# Copies known Optim files from a source rt/bin directory to a
# target rt/bin directory.
case `uname -s` in
   AIX)
      _OPTS='-d -Eignore -U -p'
      ;;

   Darwin)
      _OPTS='-n -p'
      ;;

   HP-UX)
      _OPTS=' '
      ;;

   Linux)
      _OPTS='-n'
      ;;

   SunOS)
      _OPTS='-@'
      ;;

esac
if [ -z "$1" ]; then
   echo A source rt directory is required.
   exit 1
fi
if [ -z "$2" ]; then
   echo A target rt directory is required.
   exit 1
fi
if [ ! -d $1 ]; then
   echo The source rt directory $1 does not exist.
   exit 1
fi
if [ ! -d $2 ]; then
   echo The target rt directory $2 does not exist.
   exit 1
fi

# Ensure all of the target directories exist
if [ ! -d $2/bin ]
then
    mkdir $2/bin
fi
if [ ! -d $2/etc ]
then
    mkdir $2/etc
fi
if [ ! -d $2/sbin ]
then
    mkdir $2/sbin
fi

# Copy any license files 
echo cp ${_OPTS} "$1"/bin/*.lic "$2"/bin/
cp ${_OPTS} "$1"/bin/*.lic "$2"/bin/
cp ${_OPTS} "$1"/bin/*.LIC "$2"/bin/

# Copy any product options file
if [ -f "$1"/etc/pstlocal.cfg ]
then
    echo cp ${_OPTS} "$1"/etc/pstlocal.cfg "$2"/etc/pstlocal.cfg.orig
    cp ${_OPTS} "$1"/etc/pstlocal.cfg "$2"/etc/pstlocal.cfg.orig
else
    echo file "$1"/etc/pstlocal.cfg not found!
fi
if [ -f "$1"/etc/pstserv.cfg ]
then
    echo cp ${_OPTS} "$1"/etc/pstserv.cfg "$2"/etc/pstserv.cfg.orig
    cp ${_OPTS} "$1"/etc/pstserv.cfg "$2"/etc/pstserv.cfg.orig
else
    echo file "$1"/etc/pstserv.cfg not found!
fi

# Copy any Archive files
echo cp ${_OPTS} "$1"/bin/*.af "$2"/bin/
cp ${_OPTS} "$1"/bin/*.af "$2"/bin/
cp ${_OPTS} "$1"/bin/*.AF "$2"/bin/

# Copy the password file
if [ -f "$1"/etc/pstpass ]
then
    echo cp ${_OPTS} "$1"/etc/pstpass "$2"/etc/
    cp ${_OPTS} "$1"/etc/pstpass "$2"/etc/
else
    echo File "$1"/etc/pstpass no found!
fi

# Copy the main RT shell scripts
if [ -f "$1"/rtsetenv ]
then
    echo cp ${_OPTS} "$1"/rtsetenv "$2"/rtsetenv.orig
    cp ${_OPTS} "$1"/rtsetenv "$2"/rtsetenv.orig
else
    echo File "$1"/rtsetenv not found!
fi
if [ -f "$1"/sbin/rtserver ]
then
    echo cp ${_OPTS} "$1"/sbin/rtserver "$2"/sbin/rtserver.orig
    cp ${_OPTS} "$1"/sbin/rtserver "$2"/sbin/rtserver.orig
else
    echo File "$1"/sbin/rtserver not found!
fi